@@ -12,7 +12,7 @@
 #include "job.h"
 
 #include <KMime/Content>
-#include <KMime/KMimeMessage>
+#include <KMime/Message>
 
 #include <tuple>
 
@@ -208,7 +208,7 @@ public:
     /**
      * The messages that will be fetched.
      */
-    ImapSet sequenceSet() const;
+    [[nodiscard]] ImapSet sequenceSet() const;
 
     /**
      * Set how the sequence set should be interpreted.
@@ -225,7 +225,7 @@ public:
      *          interpreted as UIDs, if @c false it should be interpreted
      *          as sequence numbers
      */
-    Q_REQUIRED_RESULT bool isUidBased() const;
+    [[nodiscard]] bool isUidBased() const;
 
     /**
      * Sets what data should be fetched.
@@ -239,9 +239,9 @@ public:
     /**
      * Specifies what data will be fetched.
      */
-    Q_REQUIRED_RESULT FetchScope scope() const;
+    [[nodiscard]] FetchScope scope() const;
 
-    // TODO: KF5: Move this to FetchScope
+    // TODO: KF6: Move this to FetchScope
     /**
      * Enables retrieving of Gmail-specific extensions
      *
@@ -261,7 +261,7 @@ public:
      * @since 4.14
      * @see setGmailExtensionsEnabled()
      */
-    bool setGmailExtensionsEnabled() const;
+    [[nodiscard]] bool setGmailExtensionsEnabled() const;
 
     /**
      * Returns the name of the mailbox the fetch job is executed on.
@@ -271,7 +271,7 @@ public:
      *
      * @since 5.6
      */
-    Q_REQUIRED_RESULT QString mailBox() const;
+    [[nodiscard]] QString mailBox() const;
 
 Q_SIGNALS:
     /**
